@@ -26,7 +26,7 @@ from layman.remotedb        import RemoteDB
 from layman.overlays.source import require_supported
 #from layman.utils import path, delete_empty_directory
 from layman.compatibility   import encode
-from layman.utils           import verify_overlay_src
+from layman.utils           import get_ans, verify_overlay_src
 from layman.mounter         import Mounter
 
 if sys.hexversion >= 0x30200f0:
@@ -126,9 +126,8 @@ class LaymanAPI(object):
                 success = self._get_installed_db().delete(
                     self._get_installed_db().select(ovl))
             except Exception as e:
-                self._error(
-                        "Exception caught removing repository '"+ovl+
-                            "':\n"+str(e))
+                self._error('Exception caught removing repository "%(repo)s":\n'
+                            '%(err)s' % {'repo': ovl, 'err': e})
             results.append(success)
             self.get_installed(dbreload=True)
         if False in results:
@@ -160,8 +159,8 @@ class LaymanAPI(object):
                 success = self._get_installed_db().add(
                     self._get_remote_db().select(ovl))
             except Exception as e:
-                self._error("Exception caught installing repository '"+ovl+
-                    "' : "+str(e))
+                self._error('Exception caught installing repository "%(repo)s":'
+                            '\n%(err)s' % {'repo': ovl, 'err': e})
             results.append(success)
             self.get_installed(dbreload=True)
         if (True in results) and update_news:
@@ -194,7 +193,7 @@ class LaymanAPI(object):
         for ovl in repos:
             if not self.is_repo(ovl):
                 self.output.error(UnknownOverlayMessage(ovl))
-                result.append(False)
+                results.append(False)
                 continue
             success = False
             try:
@@ -202,7 +201,7 @@ class LaymanAPI(object):
                     self._get_installed_db().select(ovl))
             except Exception as e:
                 self._error('Exception caught disabling repository "%(repo)s"'\
-                    ': %(err)s' % ({'repo': ovl, 'err': e}))
+                            ':\n%(err)s' % {'repo': ovl, 'err': e})
             results.append(success)
             self.get_installed(dbreload=True)
         if (True in results) and update_news:
@@ -219,7 +218,7 @@ class LaymanAPI(object):
         for ovl in repos:
             if not self.is_repo(ovl):
                 self.output.error(UnknownOverlayMessage(ovl))
-                result.append(False)
+                results.append(False)
                 continue
             success = False
             try:
@@ -227,7 +226,7 @@ class LaymanAPI(object):
                     self._get_installed_db().select(ovl))
             except Exception as e:
                 self._error('Exception caught enabling repository "%(repo)s"'\
-                    ': %(err)s' % ({'repo': ovl, 'err': e}))
+                            ':\n%(err)s' % {'repo': ovl, 'err': e})
             results.append(success)
             self.get_installed(dbreload=True)
         if (True in results) and update_news:
@@ -238,75 +237,6 @@ class LaymanAPI(object):
         return True
 
 
-    def get_all_info(self, repos, local=False):
-        """retrieves the recorded information about the repo(s)
-        specified by repo-id
-
-        @type repos: list of strings or string
-        @param repos: ['repo-id1', ...] or 'repo-id'
-        @rtype list of tuples [(str, bool, bool),...]
-        @return: dictionary of dictionaries
-        {'ovl1':
-            {'name': str,
-            'owner_name': str,
-            'owner_email': str,
-            ' homepage': str,
-            'description': str,
-            'src_uris': list of str ['uri1',...]
-            'src_type': str,
-            'priority': int,
-            'quality': str
-            'status':,
-            'official': bool,
-            'supported': bool,
-            },
-        'ovl2': {...}
-        }
-        """
-
-        repos = self._check_repo_type(repos, "get_info")
-        result = {}
-
-        if local:
-            db = self._get_installed_db()
-        else:
-            db = self._get_remote_db()
-
-        for ovl in repos:
-            if not self.is_repo(ovl):
-                self.output.error(UnknownOverlayMessage(ovl))
-                result[ovl] = ('', False, False)
-                continue
-            try:
-                overlay = db.select(ovl)
-            except UnknownOverlayException as error:
-                self._error(error)
-                result[ovl] = ('', False, False)
-            else:
-                result[ovl] = {
-                    'name': overlay.name,
-                    'owner_name': overlay.owner_name,
-                    'owner_email': overlay.owner_email,
-                    'homepage': overlay.homepage,
-                    'irc': overlay.irc,
-                    'description': [e for e in overlay.descriptions],
-                    'feeds': overlay.feeds,
-                    'sources': [(e.src, e.type, e.branch) \
-                        for e in overlay.sources],
-                    #'src_uris': [e.src for e in overlay.sources],
-                    'src_uris': overlay.source_uris(),
-                    'src_types': overlay.source_types(),
-                    #'src_types': [e.type for e in overlay.sources],
-                    'priority': overlay.priority,
-                    'quality': overlay.quality,
-                    'status': overlay.status,
-                    'official': overlay.is_official(),
-                    'supported': overlay.is_supported(),
-                    }
-
-        return result
-
-
     def get_info_str(self, repos, local=True, verbose=False, width=0):
         """retrieves the string representation of the recorded information
         about the repo(s) specified by ovl
@@ -467,18 +397,20 @@ class LaymanAPI(object):
                 #self.output.debug("API.sync(); UnknownOverlayException selecting %s" %ovl, 5)
                 #self._error(str(error))
                 fatals.append((ovl,
-                    'Failed to select overlay "' + ovl + '".\nError was: '
-                    + str(error)))
+                    'Failed to select overlay "%(repo)s".\nError was: %(error)s'
+                     % {'repo': ovl, 'err': error}))
                 self.output.debug("API.sync(); UnknownOverlayException "
-                    "selecting %s.   continuing to next ovl..." %ovl, 5)
+                    "selecting %(repo)s.   continuing to next ovl..."
+                    % {'repo': ovl}, 5)
                 continue
 
             try:
                 self.output.debug("API.sync(); try: self._get_remote_db().select(ovl)", 5)
                 ordb = self._get_remote_db().select(ovl)
             except UnknownOverlayException:
-                message = 'Overlay "%s" could not be found in the remote lists.\n' \
-                        'Please check if it has been renamed and re-add if necessary.' % ovl
+                message = 'Overlay "%(repo)s" could not be found in the remote '\
+                        'lists.\nPlease check if it has been renamed and '\
+                        're-add if necessary.' % {'repo': ovl}
                 warnings.append((ovl, message))
                 (diff_type, update_url) = (False, False)
             else:
@@ -499,8 +431,11 @@ class LaymanAPI(object):
                             warnings.append((ovl, url_msg))
                             update_success = db.update(ordb, available_srcs)
                             if not update_success:
-                                self.output.warn('Failed to update repo...readding', 2)
-                                self.readd_repos(ovl)
+                                msg = 'Failed to update source URL for overlay'\
+                                      '"%(ovl)s". Re-add overlay? [y/n]'\
+                                      % {'ovl': ovl}
+                                if get_ans(msg, color='yellow'):
+                                    self.readd_repos(ovl)
                 except Exception as error:
                     self.output.warn('Failed to perform overlay type or url updates', 2)
                     self.output.warn('    for Overlay: %s' % ovl, 2)
@@ -513,8 +448,8 @@ class LaymanAPI(object):
                     success.append((ovl,'Successfully synchronized overlay "' + ovl + '".'))
             except Exception as error:
                 fatals.append((ovl,
-                    'Failed to sync overlay "' + ovl + '".\nError was: '
-                    + str(error)))
+                    'Failed to sync overlay "%(repo)s".\nError was: %(err)s'
+                    % {'repo': ovl, 'err': error}))
 
         if output_results:
             if success:
@@ -556,8 +491,8 @@ class LaymanAPI(object):
                 'LaymanAPI.fetch_remote_list(); cache updated = %s'
                 % str(dbreload),8)
         except Exception as error:
-            self.output.error('Failed to fetch overlay list!\n Original Error was: '
-                    + str(error))
+            self.output.error('Failed to fetch overlay list!\n Original Error'
+                              ' was:\n%(err)s' % {'err': error})
             return False
         self.get_available(dbreload)
         return succeeded
