@@ -21,7 +21,12 @@ def encode(text, enc="UTF-8"):
 def fileopen(path, mode='r', enc="UTF-8"):
     """py2, py3 compatibility function"""
     try:
-        f = open(path, mode, encoding=enc)
+        # Can cause run-time when trying to encode.
+        # See https://bugs.gentoo.org/542804
+        if 'b' in mode:
+            f = open(path, mode)
+        else:
+            f = open(path, mode, encoding=enc)
     except TypeError:
         f = open(path, mode)
     return f
