@@ -87,7 +87,7 @@ class DB(DbBase):
         @rtype bool: reflect the user's decision to install overlay.
         '''
         if self.config['check_official'] and not overlay.status == 'official':
-            msg = 'Overlay "%(repo)s" is not an official. Continue install?'\
+            msg = 'Overlay "%(repo)s" is not official. Continue installing?'\
                   ' [y/n]: ' % {'repo': overlay.name}
             if not get_ans(msg, color='green'):
                 msg = 'layman will not add "%(repo)s", due to user\'s'\
@@ -107,52 +107,7 @@ class DB(DbBase):
     def add(self, overlay):
         '''
         Add an overlay to the local list of overlays.
-
-        >>> import tempfile
-        >>> tmpdir = tempfile.mkdtemp(prefix="laymantmp_")
-        >>> write = os.path.join(tmpdir, 'installed.xml')
-        >>> write2 = os.path.join(tmpdir, 'make.conf')
-        >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> from layman.config import OptionConfig
-        >>> myoptions = {'installed' :
-        ...           here + '/tests/testfiles/global-overlays.xml',
-        ...           'local_list': here + '/tests/testfiles/overlays.xml',
-        ...           'make_conf' : write2,
-        ...           'nocheck'    : 'yes',
-        ...           'storage'   : tmpdir}
-
-        >>> config = OptionConfig(myoptions)
-        >>> config.set_option('quietness', 3)
-        >>> a = DB(config)
-        >>> config.set_option('installed', write)
-        >>> b = DB(config)
-        >>> config['output'].set_colorize(False)
-
-        >>> m = MakeConf(config, b.overlays)
-        >>> m.path = write2
-        >>> success = m.write()
-        >>> success
-        True
-
-        # Commented out since it needs network access:
-
-        # >>> b.add(a.select('wrobel-stable')) #doctest: +ELLIPSIS
-        # * Running command "/usr/bin/rsync -rlptDvz --progress --delete --delete-after --timeout=180 --exclude="distfiles/*" --exclude="local/*" --exclude="packages/*" "rsync://gunnarwrobel.de/wrobel-stable/*" "/tmp/file.../wrobel-stable""...
-        # >>> c = DbBase([write, ], dict())
-        # >>> c.overlays.keys()
-        # ['wrobel-stable']
-
-        # >>> m = MakeConf(config, b.overlays)
-        # >>> [i.name for i in m.overlays] #doctest: +ELLIPSIS
-        # ['wrobel-stable']
-
-        # >>> os.unlink(write)
-        >>> os.unlink(write2)
-
-        >>> import shutil
-        >>> shutil.rmtree(tmpdir)
         '''
-
         if overlay.name not in self.overlays.keys():
             if not self._check_official(overlay):
                 return False
@@ -188,66 +143,13 @@ class DB(DbBase):
 
     def delete(self, overlay):
         '''
-        Add an overlay to the local list of overlays.
-
-        >>> import tempfile
-        >>> tmpdir = tempfile.mkdtemp(prefix="laymantmp_")
-        >>> write = os.path.join(tmpdir, 'installed.xml')
-        >>> write2 = os.path.join(tmpdir, 'make.conf')
-        >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> from layman.config import OptionConfig
-        >>> myoptions = {'installed' :
-        ...           here + '/tests/testfiles/global-overlays.xml',
-        ...           'local_list': here + '/tests/testfiles/overlays.xml',
-        ...           'make_conf' : write2,
-        ...           'nocheck'    : 'yes',
-        ...           'storage'   : tmpdir}
-
-        >>> config = OptionConfig(myoptions)
-        >>> config.set_option('quietness', 3)
-        >>> a = DB(config)
-        >>> config.set_option('installed', write)
-        >>> b = DB(config)
-        >>> config['output'].set_colorize(False)
-
-        >>> m = MakeConf(config, b.overlays)
-        >>> m.path = here + '/tests/testfiles/make.conf'
-        >>> m.read()
-        True
-
-        >>> m.path = write2
-        >>> m.write()
-        True
-
-        # >>> b.add(a.select('wrobel-stable')) #doctest: +ELLIPSIS
-        # * Running command "/usr/bin/rsync -rlptDvz --progress --delete --delete-after --timeout=180 --exclude="distfiles/*" --exclude="local/*" --exclude="packages/*" "rsync://gunnarwrobel.de/wrobel-stable/*" "/tmp/file.../wrobel-stable""...
-        # >>> b.add(a.select('wrobel')) #doctest: +ELLIPSIS
-        # * Running command "/usr/bin/svn co "https://overlays.gentoo.org/svn/dev/wrobel/" "/tmp/file.../wrobel""...
-        # >>> c = DbBase([write, ], dict())
-        # >>> c.overlays.keys()
-        # ['wrobel', 'wrobel-stable']
-
-        # >>> b.delete(b.select('wrobel'))
-        # >>> c = DbBase([write, ], dict())
-        # >>> c.overlays.keys()
-        # ['wrobel-stable']
-
-        # >>> m = MakeConf(config, b.overlays)
-        # >>> [i.name for i in m.overlays] #doctest: +ELLIPSIS
-        # ['wrobel-stable']
-
-        # >>> os.unlink(write)
-        >>> os.unlink(write2)
-
-        >>> import shutil
-        >>> shutil.rmtree(tmpdir)
+        Delete an overlay from the local list of overlays.
         '''
-
         if overlay.name in self.overlays.keys():
             overlay.delete(self.config['storage'])
             repo_ok = self.repo_conf.delete(overlay)
-            del self.overlays[overlay.name]
-            self.write(self.path)
+            self.remove(overlay, self.path)
+            self.write(self.path, remove=True)
         else:
             self.output.error('No local overlay named "' + overlay.name + '"!')
             return False
