@@ -15,6 +15,7 @@
 #
 
 from __future__ import print_function
+from __future__ import unicode_literals
 
 '''Runs external (non-doctest) test cases.'''
 
@@ -44,9 +45,15 @@ from  layman.repoconfmanager  import RepoConfManager
 from  layman.utils            import path
 from  warnings import filterwarnings, resetwarnings
 
+encoding = sys.getdefaultencoding()
+
+if encoding != 'utf-8':
+    reload(sys)
+    sys.setdefaultencoding('utf-8')
+
 HERE = os.path.dirname(os.path.realpath(__file__))
 
-class AddDeleteEnableDisableFromDB(unittest.TestCase):
+class AddDeleteEnableDisableFromConf(unittest.TestCase):
 
     def test(self):
         tmpdir = tempfile.mkdtemp(prefix='laymantmp_')
@@ -111,6 +118,97 @@ class AddDeleteEnableDisableFromDB(unittest.TestCase):
         shutil.rmtree(tmpdir)
 
 
+class AddDeleteDB(unittest.TestCase):
+    def test(self):
+        repo_name     = 'tar_test_overlay'
+        temp_dir_path = tempfile.mkdtemp(prefix='laymantmp_')
+        db_file       = os.path.join(temp_dir_path, 'installed.xml')
+        make_conf     = os.path.join(temp_dir_path, 'make.conf')
+        repo_conf     = os.path.join(temp_dir_path, 'repos.conf')
+
+        tar_source_path = os.path.join(HERE, 'testfiles', 'layman-test.tar.bz2')
+
+        (_, temp_tarball_path) = tempfile.mkstemp()
+        shutil.copyfile(tar_source_path, temp_tarball_path)
+
+        # Write overlay collection XML
+        xml_text = '''\
+<?xml version="1.0" encoding="UTF-8"?>
+<repositories xmlns="" version="1.0">
+  <repo quality="experimental" status="unofficial">
+    <name>%(repo_name)s</name>
+    <description>XXXXXXXXXXX</description>
+    <owner>
+      <email>foo@example.org</email>
+    </owner>
+    <source type="tar">file://%(temp_tarball_url)s</source>
+  </repo>
+</repositories>
+        '''\
+        % {
+            'temp_tarball_url': urllib.pathname2url(temp_tarball_path),
+            'repo_name': repo_name
+          }
+
+        (fd, temp_xml_path) = tempfile.mkstemp()
+
+        my_opts = {'installed'     : temp_xml_path,
+                   'conf_type'     : ['make.conf', 'repos.conf'],
+                   'db_type'       : 'xml',
+                   'nocheck'       : 'yes',
+                   'make_conf'     : make_conf,
+                   'repos_conf'    : repo_conf,
+                   'storage'       : temp_dir_path,
+                   'check_official': False}
+
+        with os.fdopen(fd, 'w') as f:
+            f.write(xml_text)
+
+        with fileopen(make_conf, 'w') as f:
+            f.write('PORTDIR_OVERLAY="$PORTDIR_OVERLAY"\n')
+
+        with fileopen(repo_conf, 'w') as f:
+            f.write('')
+
+        config = OptionConfig(options=my_opts)
+        config.set_option('quietness', 3)
+
+        a = DB(config)
+        config.set_option('installed', db_file)
+
+        # Add an overlay to a fresh DB file.
+        b = DB(config)
+        b.add(a.select(repo_name))
+
+        # Make sure it's actually installed.
+        specific_overlay_path = os.path.join(temp_dir_path, repo_name)
+        self.assertTrue(os.path.exists(specific_overlay_path))
+
+        # Check the DbBase to ensure that it's reading the installed.xml.
+        c = DbBase(config, paths=[db_file,])
+        self.assertEqual(list(c.overlays), ['tar_test_overlay'])
+
+        # Make sure the configs have been written to correctly.
+        conf = RepoConfManager(config, b.overlays)
+        self.assertEqual(list(conf.overlays), ['tar_test_overlay'])
+
+        # Delete the overlay from the second DB.
+        b.delete(b.select(repo_name))
+        self.assertEqual(b.overlays, {})
+
+        # Ensure the installed.xml has been cleaned properly.
+        c = DbBase(config, paths=[db_file,])
+        self.assertEqual(c.overlays, {})
+
+        conf = RepoConfManager(config, b.overlays)
+        self.assertEqual(conf.overlays, {})
+
+        # Clean up.
+        os.unlink(temp_xml_path)
+        os.unlink(temp_tarball_path)
+        shutil.rmtree(temp_dir_path)
+
+
 # Tests archive overlay types (squashfs, tar)
 # http://bugs.gentoo.org/show_bug.cgi?id=304547
 class ArchiveAddRemoveSync(unittest.TestCase):
@@ -248,7 +346,7 @@ class CLIArgs(unittest.TestCase):
                      'custom_news_pkg', 'cvs_addopts', 'cvs_command',
                      'cvs_postsync', 'cvs_syncopts', 'darcs_addopts',
                      'darcs_command', 'darcs_postsync', 'darcs_syncopts',
-                     'g-common_command', 'g-common_generateopts',
+                     'db_type', 'g-common_command', 'g-common_generateopts',
                      'g-common_postsync', 'g-common_syncopts',
                      'g-sorcery_command', 'g-sorcery_generateopts',
                      'g-sorcery_postsync', 'g-sorcery_syncopts', 'git_addopts',
@@ -258,14 +356,13 @@ class CLIArgs(unittest.TestCase):
                      'make_conf', 'mercurial_addopts', 'mercurial_command',
                      'mercurial_postsync', 'mercurial_syncopts',
                      'news_reporter', 'nocheck', 'overlay_defs', 'overlays',
-                     'quietness', 'repos_conf', 'require_repoconfig',
-                     'rsync_command', 'rsync_postsync', 'rsync_syncopts',
-                     'squashfs_addopts', 'squashfs_command',
-                     'squashfs_postsync', 'squashfs_syncopts',
-                     'storage', 'support_url_updates', 'svn_addopts',
-                     'svn_command', 'svn_postsync', 'svn_syncopts',
-                     't/f_options', 'tar_command', 'tar_postsync', 'umask',
-                     'width']
+                     'protocol_filter', 'quietness', 'repos_conf',
+                     'require_repoconfig', 'rsync_command', 'rsync_postsync',
+                     'rsync_syncopts', 'squashfs_addopts', 'squashfs_command',
+                     'squashfs_postsync', 'squashfs_syncopts', 'storage',
+                     'support_url_updates', 'svn_addopts', 'svn_command',
+                     'svn_postsync', 'svn_syncopts', 't/f_options',
+                     'tar_command', 'tar_postsync', 'umask', 'width']
         # Due to this not being a dict object, the keys() invocation is needed.
         self.assertEqual(sorted(a.keys()), test_keys)
 
@@ -330,6 +427,7 @@ class FetchRemoteList(unittest.TestCase):
         my_opts = {
                    'overlays': ['file://'\
                                 + HERE + '/testfiles/global-overlays.xml'],
+                   'db_type': 'xml',
                    'cache': cache,
                    'nocheck': 'yes',
                    'proxy': None,
@@ -344,7 +442,9 @@ class FetchRemoteList(unittest.TestCase):
         filename = api._get_remote_db().filepath(config['overlays']) + '.xml'
 
         with fileopen(filename, 'r') as b:
-            self.assertEqual(b.readlines()[19], '      A collection of ebuilds from Gunnar Wrobel [wrobel@gentoo.org].\n')
+            description = b.readlines()[19]
+            self.assertEqual(description, '      A collection of ebuilds from '\
+                                          'Gunnar Wrobel [wrobel@gentoo.org].\n')
             for line in b.readlines():
                 print(line, end='')
 
@@ -352,29 +452,16 @@ class FetchRemoteList(unittest.TestCase):
         available = api.get_available()
         self.assertEqual(available, ['wrobel', 'wrobel-stable'])
 
-        # Test the info of an overlay.
-        all_info = api.get_all_info('wrobel')
-
-        test_info = {'status': 'official', 'owner_name': None,
-                     'description': ['Test'], 'src_uris':
-                     ['https://overlays.gentoo.org/svn/dev/wrobel'],
-                     'owner_email': 'nobody@gentoo.org', 'sources':
-                     [('https://overlays.gentoo.org/svn/dev/wrobel',
-                     'Subversion', None)], 'quality': 'experimental', 'name':
-                     'wrobel', 'supported': True, 'src_types': ['Subversion'],
-                     'official': True, 'priority': 10, 'feeds': [],
-                     'irc': None, 'homepage': None}
-        info = all_info['wrobel']
-        info['src_uris'] = [e for e in info['src_uris']]
-        info['src_types'] = [e for e in info['src_types']]
         
-        self.assertEqual(info, test_info)
+        # Test the info of an overlay.
+        info = api.get_info_str(['wrobel'], verbose=True, local=False)
+        test_info = 'wrobel\n~~~~~~\nSource  : https://overlays.gentoo.org'\
+                    '/svn/dev/wrobel\nContact : nobody@gentoo.org\nType    '\
+                    ': Subversion; Priority: 10\nQuality : experimental\n\n'\
+                    'Description:\n  Test\n'
 
-        self.assertEqual(info['status'], 'official')
-        self.assertEqual(info['description'], ['Test'])
-        sources = [('https://overlays.gentoo.org/svn/dev/wrobel', 'Subversion',
-                    None)]
-        self.assertEqual(info['sources'], sources)
+        info = info['wrobel'][0].decode('utf-8')
+        self.assertEqual(info, test_info)
 
         os.unlink(filename)
         shutil.rmtree(tmpdir)
@@ -384,6 +471,7 @@ class FormatBranchCategory(unittest.TestCase):
     def _run(self, number):
         #config = {'output': Message()}
         config = BareConfig()
+
         # Discuss renaming files to "branch-%d.xml"
         filename1 = os.path.join(HERE, 'testfiles',
                 'subpath-%d.xml' % number)
@@ -424,11 +512,10 @@ class MakeOverlayXML(unittest.TestCase):
 
         ovl_dict = {
                     'name': 'wrobel',
-                    'descriptions': ['Test'],
-                    'owner_name': 'nobody',
-                    'owner_email': 'nobody@gentoo.org',
+                    'description': ['Test'],
+                    'owner': [{'name': 'nobody', 'email': 'nobody@gentoo.org'}],
                     'status': 'official',
-                    'sources': [['https://overlays.gentoo.org/svn/dev/wrobel',
+                    'source': [['https://overlays.gentoo.org/svn/dev/wrobel',
                                  'svn', '']],
                     'priority': '10',
                    }
@@ -457,17 +544,16 @@ class OverlayObjTest(unittest.TestCase):
         document = ET.parse(HERE + '/testfiles/global-overlays.xml')
         overlays = document.findall('overlay') + document.findall('repo')
         output = Message()
-
-        ovl_a = Overlay({'output': output}, overlays[0])
+        ovl_a = Overlay({'output': output, 'db_type': 'xml'}, xml=overlays[0])
         self.assertEqual(ovl_a.name, 'wrobel')
         self.assertEqual(ovl_a.is_official(), True)
         url = ['https://overlays.gentoo.org/svn/dev/wrobel']
         self.assertEqual(list(ovl_a.source_uris()), url)
-        self.assertEqual(ovl_a.owner_email, 'nobody@gentoo.org')
+        self.assertEqual(ovl_a.owners[0]['email'], 'nobody@gentoo.org')
         self.assertEqual(ovl_a.descriptions, ['Test'])
         self.assertEqual(ovl_a.priority, 10)
 
-        ovl_b = Overlay({'output': output}, overlays[1])
+        ovl_b = Overlay({'output': output, 'db_type': 'xml'}, xml=overlays[1])
         self.assertEqual(ovl_b.is_official(), False)
 
 
@@ -476,7 +562,7 @@ class OverlayObjTest(unittest.TestCase):
         overlays = document.findall('overlay') + document.findall('repo')
         output = Message()
 
-        ovl = Overlay({'output': output}, overlays[0])
+        ovl = Overlay({'output': output, 'db_type': 'xml'}, xml=overlays[0])
         test_infostr = 'wrobel\n~~~~~~\nSource  : '\
                        'https://overlays.gentoo.org/svn/dev/wrobel\nContact '\
                        ': nobody@gentoo.org\nType    : Subversion; Priority: '\
@@ -490,7 +576,7 @@ class OverlayObjTest(unittest.TestCase):
         overlays = document.findall('overlay') + document.findall('repo')
         output = Message()
 
-        ovl = Overlay({'output': output}, overlays[0])
+        ovl = Overlay({'output': output, 'db_type': 'xml'}, xml=overlays[0])
         test_short_list = 'wrobel                    [Subversion] '\
                           '(https://o.g.o/svn/dev/wrobel         )'
         self.assertEqual(ovl.short_list(80).decode('utf-8'), test_short_list)
@@ -541,6 +627,7 @@ class ReadWriteSelectListDbBase(unittest.TestCase):
         output = Message()
         config = {
                   'output': output,
+                  'db_type': 'xml',
                   'svn_command': '/usr/bin/svn',
                   'rsync_command':'/usr/bin/rsync'
                  }
@@ -574,7 +661,9 @@ class ReadWriteSelectListDbBase(unittest.TestCase):
 
     def read_db(self):
         output = Message()
-        config = {'output': output}
+        # First test if XML databasing works.
+        config = {'output': output,
+                  'db_type': 'xml',}
         db = DbBase(config, [HERE + '/testfiles/global-overlays.xml', ])
         keys = sorted(db.overlays)
         self.assertEqual(keys, ['wrobel', 'wrobel-stable'])
@@ -582,31 +671,60 @@ class ReadWriteSelectListDbBase(unittest.TestCase):
         url = ['rsync://gunnarwrobel.de/wrobel-stable']
         self.assertEqual(list(db.overlays['wrobel-stable'].source_uris()), url)
 
+        # Test JSON databasing after.
+        config['db_type'] = 'json'
+        db = DbBase(config, [HERE + '/testfiles/global-overlays.json', ])
+        keys = sorted(db.overlays)
+        self.assertEqual(keys, ['twitch153', 'wrobel-stable'])
+
+        url = ['git://github.com/twitch153/ebuilds.git']
+        self.assertEqual(list(db.overlays['twitch153'].source_uris()), url)
+
 
     def select_db(self):
         output = Message()
-        config = {'output': output}
+        config = {'output': output,
+                  'db_type': 'xml',}
         db = DbBase(config, [HERE + '/testfiles/global-overlays.xml', ])
         url = ['rsync://gunnarwrobel.de/wrobel-stable']
         self.assertEqual(list(db.select('wrobel-stable').source_uris()), url)
 
+        config['db_type'] = 'json'
+        db = DbBase(config, [HERE + '/testfiles/global-overlays.json', ])
+        url = ['git://github.com/twitch153/ebuilds.git']
+        self.assertEqual(list(db.select('twitch153').source_uris()), url)
+
 
     def write_db(self):
         tmpdir = tempfile.mkdtemp(prefix='laymantmp_')
         test_xml = os.path.join(tmpdir, 'test.xml')
+        test_json = os.path.join(tmpdir, 'test.json')
         config = BareConfig()
+
         a = DbBase(config, [HERE + '/testfiles/global-overlays.xml', ])
-        b = DbBase({'output': Message()}, [test_xml,])
+        b = DbBase({'output': Message(), 'db_type': 'xml'}, [test_xml,])
 
         b.overlays['wrobel-stable'] = a.overlays['wrobel-stable']
         b.write(test_xml)
 
-        c = DbBase({'output': Message()}, [test_xml,])
+        c = DbBase({'output': Message(), 'db_type': 'xml'}, [test_xml,])
         keys = sorted(c.overlays)
         self.assertEqual(keys, ['wrobel-stable'])
 
+        config.set_option('db_type', 'json')
+        a = DbBase(config, [HERE + '/testfiles/global-overlays.json', ])
+        b = DbBase({'output': Message(), 'db_type': 'json'}, [test_json,])
+
+        b.overlays['twitch153'] = a.overlays['twitch153']
+        b.write(test_json)
+
+        c = DbBase({'output': Message(), 'db_type': 'json'}, [test_json,])
+        keys = sorted(c.overlays)
+        self.assertEqual(keys, ['twitch153'])
+
         # Clean up:
         os.unlink(test_xml)
+        os.unlink(test_json)
         shutil.rmtree(tmpdir)
 
 
